pub enum BackgroundRepeat {
Repeat,
NoRepeat,
RepeatX,
RepeatY,
Space,
Round,
}Expand description
The background-repeat keyword.
Variants
Repeat
repeat — tile both axes. Default.
NoRepeat
no-repeat — no tiling.
RepeatX
repeat-x — tile horizontally only.
RepeatY
repeat-y — tile vertically only.
Space
space — tile with extra space between tiles to fill the box.
Round
round — tile, scaling each tile so an integer number fit.